enum LoginType {
  UserNameAndPwd,
  MobileNumber,
}

enum RegisterType {
  MobileNumber,
  Email,
}

class LoginRequest {
  final LoginType loginType;
  final ProcessorInfo processorInfo;
  final ClientInfo? clientInfo;

  LoginRequest({
    required this.loginType,
    required this.processorInfo,
    this.clientInfo,
  });

  Map<String, dynamic> toJson() {
    final map = Map<String, dynamic>();
    map['LoginType'] = loginType.index;
    map['ProcessorInfo'] = processorInfo;
    if (clientInfo != null) map['ClientInfo'] = clientInfo;
    return map;
  }
}

class ProcessorInfo {
  final String? userName;
  final String? password;

  ProcessorInfo({
    this.userName,
    this.password,
  });

  factory ProcessorInfo.fromJson(Map<String, dynamic> map) {
    return ProcessorInfo(
      userName: map['UserName'],
      password: map['Password'],
    );
  }

  Map<String, dynamic> toJson() {
    final map = Map<String, dynamic>();
    if (userName != null && userName!.isNotEmpty) map['UserName'] = userName;
    if (password != null && password!.isNotEmpty) map['Password'] = password;
    return map;
  }
}

class ClientInfo {
  final String? clientSource;

  ClientInfo({
    this.clientSource,
  });

  factory ClientInfo.fromJson(Map<String, dynamic> map) {
    return ClientInfo(
      clientSource: map['ClientSource'],
    );
  }

  Map<String, dynamic> toJson() {
    final map = Map<String, dynamic>();
    if (clientSource != null && clientSource!.isNotEmpty)
      map['ClientSource'] = clientSource;
    return map;
  }
}

class LoginResult {
  final String userCode;
  final String sessionId;
  final String? deviceId;
  LoginResult({
    required this.userCode,
    required this.sessionId,
    this.deviceId,
  });

  factory LoginResult.fromJson(Map<String, dynamic> map) {
    return LoginResult(
      userCode: map['UserCode'],
      sessionId: map['SessionId'],
      deviceId: map['DeviceId'],
    );
  }
}
